@@ -1,16 +1,21 @@
 package DateTime::TimeZone::Local::Unix;
-$DateTime::TimeZone::Local::Unix::VERSION = '1.64';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '2.39';
 
 use Cwd 3;
+use Try::Tiny;
+
 use parent 'DateTime::TimeZone::Local';
 
 sub Methods {
     return qw(
         FromEnv
-        FromEtcLocaltime
         FromEtcTimezone
+        FromEtcLocaltime
         FromEtcTIMEZONE
         FromEtcSysconfigClock
         FromEtcDefaultInit
@@ -19,11 +24,19 @@ sub Methods {
 
 sub EnvVars { return 'TZ' }
 
+## no critic (Variables::ProhibitPackageVars)
+our $EtcDir = '/etc';
+## use critic
+
+sub _EtcFile {
+    shift;
+    return File::Spec->catfile( $EtcDir, @_ );
+}
+
 sub FromEtcLocaltime {
     my $class = shift;
 
-    my $lt_file = '/etc/localtime';
-
+    my $lt_file = $class->_EtcFile('localtime');
     return unless -r $lt_file && -s _;
 
     my $real_name;
@@ -36,10 +49,10 @@ sub FromEtcLocaltime {
     $real_name ||= $class->_FindMatchingZoneinfoFile($lt_file);
 
     if ( defined $real_name ) {
-        my ( $vol, $dirs, $file ) = File::Spec->splitpath($real_name);
+        my ( undef, $dirs, $file ) = File::Spec->splitpath($real_name);
 
-        my @parts
-            = grep { defined && length } File::Spec->splitdir($dirs), $file;
+        my @parts = grep { defined && length } File::Spec->splitdir($dirs),
+            $file;
 
         foreach my $x ( reverse 0 .. $#parts ) {
             my $name = (
@@ -48,12 +61,11 @@ sub FromEtcLocaltime {
                 : $parts[$x]
             );
 
-            my $tz;
-            {
-                local $@;
+            my $tz = try {
+                ## no critic (Variables::RequireInitializationForLocalVars)
                 local $SIG{__DIE__};
-                $tz = eval { DateTime::TimeZone->new( name => $name ) };
-            }
+                DateTime::TimeZone->new( name => $name );
+            };
 
             return $tz if $tz;
         }
@@ -68,12 +80,25 @@ sub _Readlink {
     return Cwd::abs_path($link);
 }
 
+## no critic (Variables::ProhibitPackageVars)
+our $ZoneinfoDir = '/usr/share/zoneinfo';
+## use critic
+
 # for systems where /etc/localtime is a copy of a zoneinfo file
 sub _FindMatchingZoneinfoFile {
-    my $class         = shift;
+    shift;
     my $file_to_match = shift;
 
-    return unless -d '/usr/share/zoneinfo';
+    # For some reason, under at least macOS 10.13 High Sierra,
+    # /usr/share/zoneinfo is a link to a link to a directory. And no, I didn't
+    # stutter. This is fine, and it passes the -d below. But File::Find does
+    # not understand a link to be a directory, so rather than incur the
+    # overhead of telling File::Find::find() to follow symbolic links, we just
+    # resolve it here.
+    my $zone_info_dir = $ZoneinfoDir;
+    $zone_info_dir = readlink $zone_info_dir while -l $zone_info_dir;
+
+    return unless -d $zone_info_dir;
 
     require File::Basename;
     require File::Compare;
@@ -82,10 +107,11 @@ sub _FindMatchingZoneinfoFile {
     my $size = -s $file_to_match;
 
     my $real_name;
-    local $@;
-    local $SIG{__DIE__};
-    local $_;
-    eval {
+    try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
+        local $SIG{__DIE__};
+        local $_;
+
         File::Find::find(
             {
                 wanted => sub {
@@ -100,7 +126,7 @@ sub _FindMatchingZoneinfoFile {
                         # false positive
                         && File::Basename::basename($_) ne 'posixrules'
                         && File::Compare::compare( $_, $file_to_match ) == 0
-                        ) {
+                    ) {
                         $real_name = $_;
 
                         # File::Find has no mechanism for bailing in the
@@ -110,44 +136,45 @@ sub _FindMatchingZoneinfoFile {
                 },
                 no_chdir => 1,
             },
-            '/usr/share/zoneinfo',
+            $zone_info_dir,
         );
+    }
+    catch {
+        die $_ unless ref $_ && $_->{found};
     };
 
-    if ($@) {
-        return $real_name if ref $@ && $@->{found};
-        die $@;
-    }
+    return $real_name;
 }
 
 sub FromEtcTimezone {
     my $class = shift;
 
-    my $tz_file = '/etc/timezone';
-
+    my $tz_file = $class->_EtcFile('timezone');
     return unless -f $tz_file && -r _;
 
     open my $fh, '<', $tz_file
         or die "Cannot read $tz_file: $!";
-    my $name = join '', <$fh>;
-    close $fh;
+    my $name = do { local $/ = undef; <$fh> };
+    close $fh or die $!;
 
     $name =~ s/^\s+|\s+$//g;
 
     return unless $class->_IsValidName($name);
 
-    local $@;
-    local $SIG{__DIE__};
-    return eval { DateTime::TimeZone->new( name => $name ) };
+    return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
+        local $SIG{__DIE__};
+        DateTime::TimeZone->new( name => $name );
+    };
 }
 
 sub FromEtcTIMEZONE {
     my $class = shift;
 
-    my $tz_file = '/etc/TIMEZONE';
-
+    my $tz_file = $class->_EtcFile('TIMEZONE');
     return unless -f $tz_file && -r _;
 
+    ## no critic (InputOutput::RequireBriefOpen)
     open my $fh, '<', $tz_file
         or die "Cannot read $tz_file: $!";
 
@@ -159,69 +186,85 @@ sub FromEtcTIMEZONE {
         }
     }
 
-    close $fh;
+    close $fh or die $!;
 
     return unless $class->_IsValidName($name);
 
-    local $@;
-    local $SIG{__DIE__};
-    return eval { DateTime::TimeZone->new( name => $name ) };
+    return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
+        local $SIG{__DIE__};
+        DateTime::TimeZone->new( name => $name );
+    };
 }
 
 # RedHat uses this
 sub FromEtcSysconfigClock {
     my $class = shift;
 
-    return unless -r "/etc/sysconfig/clock" && -f _;
+    my $clock_file = $class->_EtcFile('sysconfig/clock');
+    return unless -r $clock_file && -f _;
 
-    my $name = $class->_ReadEtcSysconfigClock();
+    my $name = $class->_ReadEtcSysconfigClock($clock_file);
 
     return unless $class->_IsValidName($name);
 
-    local $@;
-    local $SIG{__DIE__};
-    return eval { DateTime::TimeZone->new( name => $name ) };
+    return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
+        local $SIG{__DIE__};
+        DateTime::TimeZone->new( name => $name );
+    };
 }
 
 # this is a separate function so that it can be overridden in the test suite
 sub _ReadEtcSysconfigClock {
-    my $class = shift;
+    shift;
+    my $clock_file = shift;
 
-    open my $fh, '<', '/etc/sysconfig/clock'
-        or die "Cannot read /etc/sysconfig/clock: $!";
+    open my $fh, '<', $clock_file
+        or die "Cannot read $clock_file: $!";
 
+    ## no critic (Variables::RequireInitializationForLocalVars)
     local $_;
     while (<$fh>) {
         return $1 if /^(?:TIME)?ZONE="([^"]+)"/;
     }
+
+    close $fh or die $!;
 }
 
 sub FromEtcDefaultInit {
     my $class = shift;
 
-    return unless -r "/etc/default/init" && -f _;
+    my $init_file = $class->_EtcFile('default/init');
+    return unless -r $init_file && -f _;
 
-    my $name = $class->_ReadEtcDefaultInit();
+    my $name = $class->_ReadEtcDefaultInit($init_file);
 
     return unless $class->_IsValidName($name);
 
-    local $@;
-    local $SIG{__DIE__};
-    return eval { DateTime::TimeZone->new( name => $name ) };
+    return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
+        local $SIG{__DIE__};
+        DateTime::TimeZone->new( name => $name );
+    };
 }
 
 # this is a separate function so that it can be overridden in the test
 # suite
 sub _ReadEtcDefaultInit {
-    my $class = shift;
+    shift;
+    my $init_file = shift;
 
-    open my $fh, '<', '/etc/default/init'
-        or die "Cannot read /etc/default/init: $!";
+    open my $fh, '<', $init_file
+        or die "Cannot read $init_file: $!";
 
+    ## no critic (Variables::RequireInitializationForLocalVars)
     local $_;
     while (<$fh>) {
         return $1 if /^TZ=(.+)/;
     }
+
+    close $fh or die $!;
 }
 
 1;
@@ -232,13 +275,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::TimeZone::Local::Unix - Determine the local system's time zone on Unix
 
 =head1 VERSION
 
-version 1.64
+version 2.39
 
 =head1 SYNOPSIS
 
@@ -298,15 +343,47 @@ If this file exists, it is opened and we look for a line starting like
 
 =back
 
+B<Note:> Some systems such as virtual machine boxes may lack any of these
+files. You can confirm that this is case by running:
+
+    $ ls -l /etc/localtime /etc/timezone /etc/TIMEZONE \
+        /etc/sysconfig/clock /etc/default/init
+
+If this is the case, then when checking for timezone handling you are
+likely to get an exception:
+
+    $ perl -wle 'use DateTime; DateTime->now( time_zone => "local" )'
+    Cannot determine local time zone
+
+In that case, you should consult your system F<man> pages for details on how
+to address that problem. In one such case reported to us, a FreeBSD virtual
+machine had been built without any of these files. The user was able to run
+the FreeBSD F<tzsetup> utility. That installed F</etc/localtime>, after which
+the above timezone diagnostic ran silently, I<i.e.>, without throwing an
+exception.
+
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-TimeZone/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-TimeZone can be found at L<https://github.com/houseabsolute/DateTime-TimeZone>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Dave Rolsky.
+This software is copyright (c) 2020 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
